@@ -11,5 +11,5 @@
 from .guts import *
 from .decorators import *
 
-__all__ = ('run', 'run_program', 'sub', 'argument', 'FileType', 'RestartProgram')
-__version__ = '1.0.0'
+__all__ = ('run', 'main', 'sub', 'argument', 'FileType', 'RestartProgram')
+__version__ = '1.1.0'
