@@ -18,4 +18,4 @@ def test_function2(arg1):
 def test_function3(arg1, kwarg1=None):
     pass
 
-run_program()
+run()
